[Gnucash-changes] Adjust QOF internal headers to fix qof.h.

Neil Williams codehelp at cvs.gnucash.org
Sat Oct 1 13:51:05 EDT 2005


Log Message:
-----------
Adjust QOF internal headers to fix qof.h.

Tags:
----
gnucash-gnome2-dev

Modified Files:
--------------
    gnucash/src/backend/qsf:
        qsf-xml-map.c
    gnucash/src/engine:
        gnc-engine-util.h
        gnc-engine-util.c
        qof-be-utils.h
        qof.h
        qof_book_merge.h

Revision Data
-------------
Index: qsf-xml-map.c
===================================================================
RCS file: /home/cvs/cvsroot/gnucash/src/backend/qsf/Attic/qsf-xml-map.c,v
retrieving revision 1.1.2.6
retrieving revision 1.1.2.7
diff -Lsrc/backend/qsf/qsf-xml-map.c -Lsrc/backend/qsf/qsf-xml-map.c -u -r1.1.2.6 -r1.1.2.7
--- src/backend/qsf/qsf-xml-map.c
+++ src/backend/qsf/qsf-xml-map.c
@@ -29,6 +29,7 @@
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #include <libxml/xmlschemas.h>
+#include "qof-backend-qsf.h"
 #include "qsf-xml.h"
 #include "qsf-dir.h"
 
Index: qof_book_merge.h
===================================================================
RCS file: /home/cvs/cvsroot/gnucash/src/engine/qof_book_merge.h,v
retrieving revision 1.2.2.6
retrieving revision 1.2.2.7
diff -Lsrc/engine/qof_book_merge.h -Lsrc/engine/qof_book_merge.h -u -r1.2.2.6 -r1.2.2.7
--- src/engine/qof_book_merge.h
+++ src/engine/qof_book_merge.h
@@ -21,10 +21,14 @@
  *                                                                   *
  ********************************************************************/
 
-#define _GNU_SOURCE
 #ifndef QOFBOOKMERGE_H
 #define QOFBOOKMERGE_H
 
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+#define QOF_MOD_MERGE "qof-merge"
+
 /** @addtogroup BookMerge
 
 <b>Collision handling principles.</b>\n
Index: qof-be-utils.h
===================================================================
RCS file: /home/cvs/cvsroot/gnucash/src/engine/qof-be-utils.h,v
retrieving revision 1.3.2.6
retrieving revision 1.3.2.7
diff -Lsrc/engine/qof-be-utils.h -Lsrc/engine/qof-be-utils.h -u -r1.3.2.6 -r1.3.2.7
--- src/engine/qof-be-utils.h
+++ src/engine/qof-be-utils.h
@@ -35,6 +35,7 @@
 #ifndef QOF_BE_UTILS_H
 #define QOF_BE_UTILS_H
 
+#include "gnc-trace.h"
 #include "gnc-engine-util.h"
 #include "qofbackend-p.h"
 #include "qofbook.h"
Index: gnc-engine-util.c
===================================================================
RCS file: /home/cvs/cvsroot/gnucash/src/engine/gnc-engine-util.c,v
retrieving revision 1.29.4.5
retrieving revision 1.29.4.6
diff -Lsrc/engine/gnc-engine-util.c -Lsrc/engine/gnc-engine-util.c -u -r1.29.4.5 -r1.29.4.6
--- src/engine/gnc-engine-util.c
+++ src/engine/gnc-engine-util.c
@@ -30,7 +30,7 @@
 #include <glib.h>
 #include <stdlib.h>
 #include <string.h>
-#include <qof.h>
+#include "qof.h"
 #include "gnc-engine-util.h"
 
 
Index: qof.h
===================================================================
RCS file: /home/cvs/cvsroot/gnucash/src/engine/qof.h,v
retrieving revision 1.2.4.7
retrieving revision 1.2.4.8
diff -Lsrc/engine/qof.h -Lsrc/engine/qof.h -u -r1.2.4.7 -r1.2.4.8
--- src/engine/qof.h
+++ src/engine/qof.h
@@ -73,12 +73,16 @@
 */
 /** @} */
 
+#include "qofid.h"
+#include "gnc-trace.h"
 #include "gnc-date.h"
-#include "gnc-engine-util.h"
 #include "gnc-numeric.h"
 #include "gnc-event.h"
+#include "gnc-engine-util.h"
 #include "guid.h"
 #include "kvp_frame.h"
+#include "kvp-util.h"
+#include "kvp-util-p.h"
 #include "qofbackend.h"
 #include "qofid-p.h"
 #include "qofinstance-p.h"


More information about the gnucash-changes mailing list
Index: gnc-engine-util.h
===================================================================
RCS file: /home/cvs/cvsroot/gnucash/src/engine/gnc-engine-util.h,v
retrieving revision 1.32.4.9
retrieving revision 1.32.4.10
diff -Lsrc/engine/gnc-engine-util.h -Lsrc/engine/gnc-engine-util.h -u -r1.32.4.9 -r1.32.4.10
--- src/engine/gnc-engine-util.h
+++ src/engine/gnc-engine-util.h
@@ -1,5 +1,5 @@
 /********************************************************************\
  * gnc-engine-util.h -- GnuCash engine utility functions            *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -22,7 +22,7 @@
 /** @addtogroup Utilities
     @{ */
 /** @file gnc-engine-util.h 
-    @brief GnuCash engine utility functions 
+    @brief QOF utility functions
     @author Copyright (C) 1997 Robin D. Clark <rclark at cs.hmc.edu>
     @author Copyright (C) 2000 Bill Gribble <grib at billgribble.com>
     @author Copyright (C) 1997-2002,2004 Linas Vepstas <linas at linas.org>
@@ -34,7 +34,7 @@
 #include <glib.h>
 #include <stddef.h>
 #include "config.h"
-#include "gnc-trace.h"  // XXX eliminate me eventually
+#include "qof.h"
 
 /** Macros *****************************************************/
 
@@ -150,10 +150,16 @@
    @{
 */
    
-/** \brief Initialise the Query Object Framework */
+/** \brief Initialise the Query Object Framework 
+
+Used for non-Guile applications or test routines.
+*/
 void qof_init (void);
 
-/** \brief Safely close down the Query Object Framework */
+/** \brief Safely close down the Query Object Framework 
+
+Used for non-Guile applications or test routines.
+*/
 void qof_close (void);
 
 /** @} */
@@ -223,13 +229,13 @@
  * cached the strings are just plain C strings.
  */
 
-/** Get the gnc_string_cache.  Create it if it doesn't exist already */
+/** Get the gnc_string_cache.  Create it if it doesn't exist already
+
+\todo hide the gcache as a static */
 GCache* gnc_engine_get_string_cache(void);
 
 void gnc_engine_string_cache_destroy (void);
 
-/* TODO: hide the gcache as a static */
-
 /* You can use this function as a destroy notifier for a GHashTable
    that uses common strings as keys (or values, for that matter.) */
 void gnc_string_cache_remove(gpointer key);
@@ -1,5 +1,5 @@
 /********************************************************************\
- * gnc-engine-util.h -- GnuCash engine utility functions            *
+ * gnc-engine-util.h -- QOF utility functions                       *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *